pub mod amazon;
pub mod blizzard;
pub mod epicgames;
mod error;
pub mod gog;
pub mod manager;
pub mod origin;
pub mod prelude;
pub mod riotgames;
pub mod steam;
pub mod ubisoft;
mod utils;
